[![Build Status](https://travis-ci.com/piccolo-orm/piccolo_api.svg?branch=master)](https://travis-ci.com/piccolo-orm/piccolo_api)

[![Documentation Status](https://readthedocs.org/projects/piccolo-api/badge/?version=latest)](https://piccolo-api.readthedocs.io/en/latest/?badge=latest)

[![Coverage Status](https://coveralls.io/repos/github/piccolo-orm/piccolo_api/badge.svg?branch=master)](https://coveralls.io/github/piccolo-orm/piccolo_api?branch=master)

# Piccolo API

Utilities for easily exposing [Piccolo](https://piccolo-orm.readthedocs.io/en/latest/) models as REST endpoints in ASGI apps, such as [Starlette](https://starlette.io) and [FastAPI](https://fastapi.tiangolo.com/).

Includes a bunch of useful ASGI middleware:

 * Session Auth
 * Token Auth
 * Rate Limiting
 * CSRF
 * Content Security Policy (CSP)
 * And more

You can read the docs [here](https://piccolo-api.readthedocs.io/en/latest/).
